/*******************************************************************************
Sam Langfield and Marco Pagano (2015)
"Bank bias in Europe: Effects on Systemic Risk and Growth"
Economic Policy
*******************************************************************************/

/*******************************************************************************
Growth regressions
*******************************************************************************/

/*******************************************************************************
HOUSEKEEPING
*******************************************************************************/

version 13.0

*Set your working directory here:
cd "C:\Users\SPL\Dropbox\Research\Pagano-Langfield_EP_Bank-bias\Data\CLEAN"

clear all
cap log close
set more off
set scheme s1color

insheet using B_WorldBank.csv, comma

/*******************************************************************************
LABEL VARIABLES
*******************************************************************************/

label var ta_gdp "Bank TA / GDP (%), from various sources (see Annex 1)"
label var abiad_bank_supervision "Index of bank supervision, norm{0,1}, from Abiad etal 2008"
label var abiad_securitymarket_lib "Index of security mkt liberalisation, norm{0,1}, from Abiad etal 2008"
label var abiad_creditcontrols "Index of credit controls, norm{0,1}, from Abiad etal 2008"
label var abiad_creditceilings "Index of credit ceilings, norm{0,1}, from Abiad etal 2008"
label var abiad_intratecontrols "Index of interest rate lib, norm{0,1}, from Abiad etal 2008"
label var abiad_entrybarriers "Index of entry barriers, norm{0,1}, from Abiad etal 2008"
label var abiad_privatization "Index of privatization, norm{0,1}, from Abiad etal 2008"
label var inflation "Inflation, consumer prices (annual %), from WB"
label var rgdp "GDP (constant 2005 US$), from WB"
label var ngdp "Nominal GDP (Current USD), from WB GFDD"
label var rgdp_percapita "GDP per capita (Constant 2005 USD), from WB GFDD"
label var stockmktreturn "Nominal stock market return (%, year-on-year), from WB GFDD"
label var stmktcap "STOCK MARKET CAPITALIZATION to GDP (%), from WB"
label var ofagdp "OTHER FINANCIAL INSTITUTIONS ASSETS to GDP (%), from WB FinStr Dataset, vNov2013"
label var pcrdbgdp "PRIVATE CREDIT BY DEPOSIT MONEY BANKS to GDP (%), from WB FinStr Dataset, vNov2013"
label var pcrdbofgdp "PRIVATE CREDIT BY DEPOSIT MONEY BANKS AND OTHER FINANCIAL INSTITUTIONS to GDP (%), from WB FinStr Dataset, vNov2013"
label var stvaltraded "STOCK MARKET TOTAL VALUE TRADED to GDP (%), from WB FinStr Dataset, vNov2013"
label var stturnover "STOCK MARKET TURNOVER RATIO (%), from WB FinStr Dataset, vNov2013"
label var prbond "PRIVATE BOND MARKET CAPITALIZATION to GDP (%), from WB FinStr Dataset, vNov2013"
label var stvaltraded_composite "STOCK MKT TTL VAL TRADED / GDP (%), comp from WB FinStr + Levine 2002"
label var stmktcap_composite "STOCK MKT CAP TO GDP (%), comp from WB FinStr + Levine 2002 + Zingales"
label var pcrdbgdp_composite "PRIVATE CREDIT BY DEPOSIT MONEY BANKS to GDP (%), comp WB + Levine"
label var pcrdbofgdp_composite "PRIVATE CREDIT BY DEPOSIT MONEY BANKS + OFIs to GDP (%), comp WB + Levine"
label var prbond_composite "PRIV BOND MARKET CAP to GDP (%), comp from WB + Levine + Zingales"
label var dhpr "Real house prices (%YoY change), composite BIS series"
label var countryname "Country name"
label var countrycode "Country code: ISO 3166-1 alpha-3"


/*******************************************************************************
GENERATE VARIABLES
*******************************************************************************/

encode countrycode, gen(cncode)
xtset cncode year 

*dGDP
gen d1rgdp_percapita = (rgdp_percapita - L1.rgdp_percapita) / L1.rgdp_percapita
label var d1rgdp_percapita "%YoY change in GDP per capita (Constant 2005 USD)"

*Structure
gen STR_ta_stockbond = ln(ta_gdp_composite/(stmktcap_composite+prbond_composite))
label var STR_ta_stockbond "Structure: Log of TA divided by stock and bond mkt cap"

*Structure alternative definitions (for Table 5)
gen STR_ta_stmktcap = ln(ta_gdp_composite/stmktcap_composite)
gen STR_pcrd_stockbond = ln(pcrdbgdp_composite/(stmktcap_composite+prbond_composite))
gen STR_pcrd_stmktcap = ln(pcrdbgdp_composite/stmktcap_composite)

*Structure not logged
gen ta_stockbond = ta_gdp_composite/(stmktcap_composite+prbond_composite)
label var ta_stockbond "TA divided by stock and bond mkt cap"

*Housing market variables
gen d_crisis_hp_5pc = .
replace d_crisis_hp_5pc = 0 if (dhpr>-5 & dhpr<99999)
replace d_crisis_hp_5pc = 1 if dhpr<=-5
label var d_crisis_hp_5pc "Dummy equals 1 if yearly real house price change =< 5%; 0 otherwise"

gen d_crisis_hp_10pc = .
replace d_crisis_hp_10pc = 0 if (dhpr>-10 & dhpr<99999)
replace d_crisis_hp_10pc = 1 if dhpr<=-10
label var d_crisis_hp_10pc "Dummy equals 1 if yearly real house price change =< 10%; 0 otherwise"

gen d_boom_hp_10pc = .
replace d_boom_hp_10pc = 0 if (dhpr<10)
replace d_boom_hp_10pc = 1 if (dhpr>=10 & dhpr<99999)
label var d_boom_hp_10pc "Dummy equals 1 if yearly real house price change >10%; 0 otherwise"

*Stock market variables
gen rstockmktreturn = stockmktreturn - inflation
replace rstockmktreturn = . if rstockmktreturn<-100
replace rstockmktreturn = . if rstockmktreturn>1000
label var rstockmktreturn "Real stock market return (%, year-on-year), from WB GFDD"

gen d_crisis_stkmkt_10pc = .
replace d_crisis_stkmkt_10pc = 0 if (rstockmktreturn > -10 & rstockmktreturn < 1000)
replace d_crisis_stkmkt_10pc = 1 if rstockmktreturn <= -10
label var d_crisis_stkmkt_10pc "Dummy equals 1 if yearly real stock mkt return < 10%; 0 otherwise"

gen d_crisis_stkmkt_20pc = .
replace d_crisis_stkmkt_20pc = 0 if (rstockmktreturn > -20 & rstockmktreturn < 1000)
replace d_crisis_stkmkt_20pc = 1 if rstockmktreturn <= -20
label var d_crisis_stkmkt_20pc "Dummy equals 1 if yearly real stock mkt return < 20%; 0 otherwise"

gen d_boom_stkmkt_20pc = .
replace d_boom_stkmkt_20pc = 0 if (rstockmktreturn > 20 & rstockmktreturn < 1000)
replace d_boom_stkmkt_20pc = 1 if rstockmktreturn <= 20
label var d_boom_stkmkt_20pc "Dummy equals 1 if yearly real stock mkt return > 20%; 0 otherwise"


/*
GEN COUNTRY VARS
*/
gen d_europe=0
replace d_europe=1 if countrycode=="SVN"
replace d_europe=1 if countrycode=="SVK"
replace d_europe=1 if countrycode=="MLT"
replace d_europe=1 if countrycode=="LUX"
replace d_europe=1 if countrycode=="HUN"
replace d_europe=1 if countrycode=="DEU"
replace d_europe=1 if countrycode=="GRC"
replace d_europe=1 if countrycode=="AUT"
replace d_europe=1 if countrycode=="ITA"
replace d_europe=1 if countrycode=="IRL"
replace d_europe=1 if countrycode=="GBR"
replace d_europe=1 if countrycode=="CZE"
replace d_europe=1 if countrycode=="FIN"
replace d_europe=1 if countrycode=="FRA"
replace d_europe=1 if countrycode=="BEL"
replace d_europe=1 if countrycode=="PRT"
replace d_europe=1 if countrycode=="POL"
replace d_europe=1 if countrycode=="ESP"
replace d_europe=1 if countrycode=="DNK"
replace d_europe=1 if countrycode=="NOR"
replace d_europe=1 if countrycode=="CHE"
replace d_europe=1 if countrycode=="NLD"
replace d_europe=1 if countrycode=="SWE"
replace d_europe=1 if countrycode=="BGR"
replace d_europe=1 if countrycode=="CYP"
replace d_europe=1 if countrycode=="EST"
replace d_europe=1 if countrycode=="HRV"
replace d_europe=1 if countrycode=="IMY"
replace d_europe=1 if countrycode=="ISL"
replace d_europe=1 if countrycode=="LIE"
replace d_europe=1 if countrycode=="LVA"
replace d_europe=1 if countrycode=="MCO"
replace d_europe=1 if countrycode=="ROM"

label var d_europe "Dummy equals 1 if country is in geographic Europe; 0 otherwise"

*SAVE
save X2_WorldBank_prepped, replace



/*******************************************************************************
COLLAPSE YEARLY FREQUENCY TO NON-OVERLAPPING 5-year PERIODS
*******************************************************************************/

use X2_WorldBank_prepped, clear

*Generate time dummies for five-year non-overlapping periods
gen time_period = 0 if year<=1987
replace time_period = 1 if (year>=1988 & year<=1992)
replace time_period = 2 if (year>=1993 & year<=1997)
replace time_period = 3 if (year>=1998 & year<=2002)
replace time_period = 4 if (year>=2003 & year<=2007)
replace time_period = 5 if (year>=2008 & year<=2011)
drop if time_period==0

*Generate five-year average real GDP per capita growth rate
bys time_period cncode: egen mean_d1rgdp = mean(d1rgdp)

*Generate structure variables
bys time_period cncode: egen mean_STR_ta_stockbond = mean(STR_ta_stockbond)
bys time_period cncode: egen mean_STR_ta_stmktcap = mean(STR_ta_stmktcap)
bys time_period cncode: egen mean_STR_pcrd_stockbond = mean(STR_pcrd_stockbond)
bys time_period cncode: egen mean_STR_pcrd_stmktcap = mean(STR_pcrd_stmktcap)

*Gen housing crisis and boom variables
bys time_period cncode: egen mean_dhpr = mean(dhpr)

gen d_5ycrisis_hp_5pc = .
replace d_5ycrisis_hp_5pc = 0 if (mean_dhpr>-5 & mean_dhpr<100)
replace d_5ycrisis_hp_5pc = 1 if mean_dhpr<=-5

gen d_5yboom_hp_5pc = .
replace d_5yboom_hp_5pc = 0 if (mean_dhpr<5)
replace d_5yboom_hp_5pc = 1 if (mean_dhpr>=5 & mean_dhpr<100)

*Gen stock market crisis and boom variables
bys time_period cncode: egen mean_rstockmktreturn = mean(rstockmktreturn)

gen d_5ycrisis_st_10pc = .
replace d_5ycrisis_st_10pc = 0 if (mean_rstockmktreturn>-10 & mean_rstockmktreturn<100)
replace d_5ycrisis_st_10pc = 1 if mean_rstockmktreturn<=-10

gen d_5yboom_st_10pc = .
replace d_5yboom_st_10pc = 0 if (mean_rstockmktreturn<10)
replace d_5yboom_st_10pc = 1 if (mean_rstockmktreturn>=10 & mean_rstockmktreturn<100)

*FINANCIAL REFORM INSTRUMENTS (for Table 6 and Table 7)
xtset cncode year 
gen L6abiad_bank_supervision = L6.abiad_bank_supervision
bys time_period cncode: egen mean_L6abiad_bank_sup= mean(L6abiad_bank_supervision)

xtset cncode year 
gen L6abiad_securitymarket_lib = L6.abiad_securitymarket_lib
bys time_period cncode: egen mean_L6abiad_secmktlib= mean(L6abiad_securitymarket_lib)

xtset cncode year 
gen L6abiad_creditceilings = L6.abiad_creditceilings
bys time_period cncode: egen mean_L6abiad_creditceilings= mean(L6abiad_creditceilings)

xtset cncode year 
gen L6abiad_intratecontrols = L6.abiad_intratecontrols
bys time_period cncode: egen mean_L6abiad_intratecontrols= mean(L6abiad_intratecontrols)

xtset cncode year 
gen L6abiad_privatization = L6.abiad_privatization
bys time_period cncode: egen mean_L6abiad_privatization= mean(L6abiad_privatization)

xtset cncode year 
gen L6abiad_entrybarriers = L6.abiad_entrybarriers
bys time_period cncode: egen mean_L6abiad_entrybarriers= mean(L6abiad_entrybarriers)

*Collapse dataset to five-yearly periods
duplicates drop time_period cncode, force
order time_period

*Drop variables which are observed at yearly frequency
drop year rgdp* ngdp inflation *composite *stockmktreturn dhpr abiad* d1rgdp_percapita STR* d_crisis*
drop L6abiad*

xtset cncode time_period 
save X2_WorldBank_prepped_5y_nonoverlap, replace

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
	


/*******************************************************************************
TABLE 3: GDP growth and the bank-market ratio (country-level panel regressions)
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear
	
*Col1: housing crisis interaction only
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table3", excel cttop("Housing crisis") replace ///
	drop(i.year)

*Figure 10a: Illustration of predicted effect (housing)
margins, at(mean_STR_ta_stockbond=(-.5822387 -.5 (0.1) 1.5 1.529542)) over(d_5ycrisis_hp_5pc) atmeans

marginsplot, ///
	recastci(rarea) ci1(color(gs14)) ci2(color(gs9)) ///
	recast(line) plot1(lcolor(gs7) lpattern("--") lwidth(medthick)) ///
				plot2(lcolor(gs0) lpattern(dot) lwidth(medthick)) ///
				xlabel(-.5822387 "5" .1244442 "25" .6073711 "50" 1.081815 "75" 1.710237 "95") ///
	legend(rows(1) order(- "Predicted effect during:" 4 "crises" 3 "no crisis") region(lcolor(white))) ///
	xtitle("") ///
	ytitle("" , size(large)) ///
		ylabel(-.06 " " -.04 "-4%" 0 "0" .04 "4%" .08 "8%") ///
	///
	title("   Housing market crisis", size(large)) ///
	ysize(1) xsize(1) ///  
		graphregion(margin(vsmall)) ///
	name(Fig10a, replace) scale(1)

	
	
*Col2: housing crisis AND housing boom interactions
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)	
	
	kkk

outreg2 using "Z2_Table3", excel cttop("Housing crisis and boom") ///
	drop(i.year)
	
		
*Col3: stock market crisis interaction only
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table3", excel cttop("Stock crisis") ///
	drop(i.year)
	

*Figure 10b: Illustration of predicted effect (stock)
margins, at(mean_STR_ta_stockbond=(-.5674059 -.5 (0.1) 1.5 1.706327)) over(d_5ycrisis_st_10pc) atmeans

marginsplot, ///
	recastci(rarea) ci1(color(gs14)) ci2(color(gs9)) ///
	recast(line) plot1(lcolor(gs7) lpattern("--") lwidth(medthick)) ///
				plot2(lcolor(gs0) lpattern(dot) lwidth(medthick)) ///
				xlabel(-.5674059 "5" .1607396 "25" .5857393 "50" 1.033488 "75" 1.706327 "95") ///
	legend(rows(1) order(3 4) region(lcolor(white)) ///
		label(3 "Normal times") label(4 "During housing market crashes")) ///
	xtitle("") ///
	ytitle("", size(large)) ///
		ylabel(-.06 " " -.04 "-4%" 0 "0" .04 "4%" .08 "8%") ///
	///
	title("   Stock market crisis", size(large)) ///
	ysize(1) xsize(1) ///  
		graphregion(margin(vsmall)) ///
	name(Fig10b, replace) scale(1)
	
grc1leg Fig10a Fig10b, ///
	scale(1) name("combine", replace) graphregion(margin(medsmall)) legendfrom(Fig10a) rows(1) ///
	l2title("GDP growth", size(med)) l1title("(year-on-year change in real GDP per capita)", size(medsmall)) ///
	b1title("Bank-market ratio", size(med)) span position(12) ///
	b2title("(percentile in the distribution of" "bank total assets to stock and bond market cap)", size(medsmall))

graph display combine, ysize(10) xsize(13)

graph export Z_Fig10.emf, replace 

window manage close graph Fig10a
window manage close graph Fig10b

*Col4: stock market crisis AND boom interactions
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc##d_5yboom_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table3", excel cttop("Stock crisis and boom") ///
	drop(i.year)


/*******************************************************************************
TABLE 4: Robustness for GDP growth and the bank-market ratio (country-level panel regressions at five-year frequency, excluding 2008-11 observations)
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear

drop if time_period==5 //drop if year>=2008 & year<=2011
	
*Col1: housing crisis interaction only
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table4", excel cttop("Housing crisis") replace ///
	drop(i.year)
	
*Col2: housing crisis AND housing boom interactions
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)	

outreg2 using "Z2_Table4", excel cttop("Housing crisis and boom") replace ///
	drop(i.year)
		
*Col3: stock market crisis interaction only
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table4", excel cttop("Stock crisis") replace ///
	drop(i.year)

*Col4: stock market crisis AND boom interactions
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc##d_5yboom_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table4", excel cttop("Stock crisis and boom") replace ///
	drop(i.year)
	
	
/*******************************************************************************
TABLE 5: Robustness for GDP growth and the bank-market ratio (country-level panel regressions at five-year frequency, with various definitions of the bank-market ratio)
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear

*Col1
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table5", excel cttop("Total assets / Stock and bond market cap") replace ///
	drop(i.year)

*Col2
xtreg mean_d1rgdp c.mean_STR_ta_stmktcap##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)	
	
outreg2 using "Z2_Table5", excel cttop("Total assets / Stock market cap") ///
	drop(i.year)
	
*Col3
xtreg mean_d1rgdp c.mean_STR_pcrd_stockbond##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
outreg2 using "Z2_Table5", excel cttop("Private bank credit / Stock and bond market cap") ///
	drop(i.year)
	
*Col4
xtreg mean_d1rgdp c.mean_STR_pcrd_stmktcap##d_5ycrisis_hp_5pc##d_5yboom_hp_5pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)	
	
outreg2 using "Z2_Table5", excel cttop("Private bank credit / Stock market cap") ///
	drop(i.year)
	

	
/*******************************************************************************
*TABLE 6 AND TABLE 7
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear

*Prepare dataset
tabulate time_period, gen(timeperioddummy)
drop timeperioddummy1 timeperioddummy2 //colinear

*Generate housing crisis interaction terms manually
gen mean_STRNd_crisis_hp_5pc = mean_STR_ta_stockbond*d_5ycrisis_hp_5pc
gen ab_bank_sup_hcrisis = mean_L6abiad_bank_sup*d_5ycrisis_hp_5pc
gen ab_secmkt_hcrisis = mean_L6abiad_secmktlib*d_5ycrisis_hp_5pc
gen ab_credcec_hcrisis = mean_L6abiad_creditceilings*d_5ycrisis_hp_5pc
gen ab_intratecontrols_hcrisis = mean_L6abiad_intratecontrols*d_5ycrisis_hp_5pc
gen ab_privatization_hcrisis = mean_L6abiad_privatization*d_5ycrisis_hp_5pc
gen ab_entrybarriers_hcrisis = mean_L6abiad_entrybarriers*d_5ycrisis_hp_5pc

*Generate stock crisis interaction terms manually
gen mean_STRNd_crisis_st_10pc = mean_STR_ta_stockbond*d_5ycrisis_st_10pc
gen ab_bank_sup_scrisis10 = mean_L6abiad_bank_sup*d_5ycrisis_st_10pc
gen ab_secmkt_scrisis10 = mean_L6abiad_secmktlib*d_5ycrisis_st_10pc
gen ab_credcec_scrisis10 = mean_L6abiad_creditceilings*d_5ycrisis_st_10pc
gen ab_intratecontrols_scrisis10 = mean_L6abiad_intratecontrols*d_5ycrisis_st_10pc
gen ab_privatization_scrisis10 = mean_L6abiad_privatization*d_5ycrisis_st_10pc
gen ab_entrybarriers_scrisis10 = mean_L6abiad_entrybarriers*d_5ycrisis_st_10pc

*Generate subsample dummy
gen sample_table6 = 1
replace sample_table6 = . if missing(mean_L6abiad_bank_sup)
replace sample_table6 = . if missing(mean_L6abiad_secmktlib)
replace sample_table6 = . if missing(mean_L6abiad_creditceilings)
replace sample_table6 = . if missing(mean_L6abiad_intratecontrols)
replace sample_table6 = . if missing(mean_L6abiad_privatization)
replace sample_table6 = . if missing(mean_L6abiad_entrybarriers)

*REGRESSIONS

*Col1
xtivreg2 mean_d1rgdp ///
		d_5ycrisis_hp_5pc ///  
			timeperioddummy* ///
		(mean_STR_ta_stockbond mean_STRNd_crisis_hp_5pc ///
			= ///
			mean_L6abiad_bank_sup ab_bank_sup_hcrisis ///
			mean_L6abiad_secmktlib ab_secmkt_hcrisis ///
			mean_L6abiad_creditceilings ab_credcec_hcrisis ///
			mean_L6abiad_intratecontrols ab_intratecontrols_hcrisis ///
			mean_L6abiad_privatization ab_privatization_hcrisis ///
			mean_L6abiad_entrybarriers ab_entrybarriers_hcrisis ///
			///
			), ///
		 fe first i(cncode) cluster(cncode)
		 	 
outreg2 using "Z2_Table7", excel cttop("Housing market crisis") replace ///
	drop(i.year)

xtoverid //Sargan
xtoverid, robust //Hansen's J


*Col2
xtivreg2 mean_d1rgdp ///
		d_5ycrisis_st_10pc ///  
			timeperioddummy* ///
		(mean_STR_ta_stockbond mean_STRNd_crisis_st_10pc ///
			= ///
			mean_L6abiad_bank_sup ab_bank_sup_scrisis10 ///
			mean_L6abiad_secmktlib ab_secmkt_scrisis10 ///
			mean_L6abiad_creditceilings ab_credcec_scrisis10 ///
			mean_L6abiad_intratecontrols ab_intratecontrols_scrisis10 ///
			mean_L6abiad_privatization ab_privatization_scrisis10 ///
			mean_L6abiad_entrybarriers ab_entrybarriers_scrisis10 ///
			///
			), ///
		 fe first i(cncode) cluster(cncode)
		 
outreg2 using "Z2_Table7", excel cttop("Stock market crisis") ///
	drop(i.year)
		 
xtoverid //Sargan
xtoverid, robust //Hansen's J


*EXTENSION TO BOOMS (NOT REPORTED IN PAPER)

*Generate housing boom interaction terms manually
gen mean_STRNd_boom_hp_5pc = mean_STR_ta_stockbond*d_5yboom_hp_5pc
gen ab_bank_sup_hboom = mean_L6abiad_bank_sup*d_5yboom_hp_5pc
gen ab_secmkt_hboom = mean_L6abiad_secmktlib*d_5yboom_hp_5pc
gen ab_credcec_hboom = mean_L6abiad_creditceilings*d_5yboom_hp_5pc
gen ab_intratecontrols_hboom = mean_L6abiad_intratecontrols*d_5yboom_hp_5pc
gen ab_privatization_hboom = mean_L6abiad_privatization*d_5yboom_hp_5pc
gen ab_entrybarriers_hboom = mean_L6abiad_entrybarriers*d_5yboom_hp_5pc

*Generate stock boom interaction terms manually
gen mean_STRNd_boom_st_10pc = mean_STR_ta_stockbond*d_5yboom_st_10pc
gen ab_bank_sup_sboom10 = mean_L6abiad_bank_sup*d_5yboom_st_10pc
gen ab_secmkt_sboom10 = mean_L6abiad_secmktlib*d_5yboom_st_10pc
gen ab_credcec_sboom10 = mean_L6abiad_creditceilings*d_5yboom_st_10pc
gen ab_intratecontrols_sboom10 = mean_L6abiad_intratecontrols*d_5yboom_st_10pc
gen ab_privatization_sboom10 = mean_L6abiad_privatization*d_5yboom_st_10pc
gen ab_entrybarriers_sboom10 = mean_L6abiad_entrybarriers*d_5yboom_st_10pc

xtivreg2 mean_d1rgdp ///
		d_5ycrisis_hp_5pc d_5yboom_hp_5pc ///  
			timeperioddummy* ///
		(mean_STR_ta_stockbond mean_STRNd_crisis_hp_5pc mean_STRNd_boom_hp_5pc ///
			= ///
			mean_L6abiad_bank_sup ab_bank_sup_hcrisis ab_bank_sup_hboom ///
			mean_L6abiad_secmktlib ab_secmkt_hcrisis ab_secmkt_hboom ///
			mean_L6abiad_creditceilings ab_credcec_hcrisis ab_credcec_hboom ///
			mean_L6abiad_intratecontrols ab_intratecontrols_hcrisis ab_intratecontrols_hboom ///
			mean_L6abiad_privatization ab_privatization_hcrisis ab_privatization_hboom ///
			mean_L6abiad_entrybarriers ab_entrybarriers_hcrisis ab_entrybarriers_hboom ///
			///
			), ///
		 fe first i(cncode) cluster(cncode)
		 
xtoverid //Sargan
xtoverid, robust //Hansen's J 

xtivreg2 mean_d1rgdp ///
		d_5ycrisis_st_10pc d_5yboom_st_10pc ///  
			timeperioddummy* ///
		(mean_STR_ta_stockbond mean_STRNd_crisis_st_10pc mean_STRNd_boom_st_10pc ///
			= ///
			mean_L6abiad_bank_sup ab_bank_sup_scrisis10 ab_bank_sup_sboom10 ///
			mean_L6abiad_secmktlib ab_secmkt_scrisis10 ab_secmkt_sboom10 ///
			mean_L6abiad_creditceilings ab_credcec_scrisis10 ab_credcec_sboom10 ///
			mean_L6abiad_intratecontrols ab_intratecontrols_scrisis10 ab_intratecontrols_sboom10 ///
			mean_L6abiad_privatization ab_privatization_scrisis10 ab_privatization_sboom10 ///
			mean_L6abiad_entrybarriers ab_entrybarriers_scrisis10 ab_entrybarriers_sboom10 ///
			///
			), ///
		 fe first i(cncode) cluster(cncode)

xtoverid //Sargan
xtoverid, robust //Hansen's J



/*******************************************************************************
*Predicted effect (for calculations in paper para begininning "To gauge the economic magnitude of the predicted effect...")
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear

*Re-run Table 3, col I
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc ///
	i.time_period ///
	, ///
	vsquish fe vce(cluster cncode)
	
margins, at(mean_STR_ta_stockbond=(1.1515791 1.3228805)) atmeans over(d_5ycrisis_hp_5pc) //To calculate the predicted economic effect of the actual increase in the bank-market ratio between 1990 and 2011. 

/*
Print of results from previous -margin- command:

---------------------------------------------------------------------------------------
                      |            Delta-method
                      |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------------+----------------------------------------------------------------
_at#d_5ycrisis_hp_5pc |
                 1 0  |   .0100474   .0039854     2.52   0.012     .0022362    .0178585
                 1 1  |  -.0190288   .0046977    -4.05   0.000    -.0282361   -.0098216
                 2 0  |   .0066153   .0051727     1.28   0.201    -.0035231    .0167536
                 2 1  |  -.0253942   .0060684    -4.18   0.000     -.037288   -.0135004
---------------------------------------------------------------------------------------

"We find that an increase in a countrys bank-market ratio from 3.2 in 1990 to 
3.8 in 2011 is associated with a slowdown in the growth rate of 0.3 percentage points
per year in normal times and 0.6 percentage points per year during housing market crises."

--> To replicate 0.3pp during normal times, calculate .0066153 - .0100474 = -0.003432
--> To replicate 0.6pp during housing crises, calculate -.0253942 - -.0190288 = -0.006365
*/

margins, at(mean_STR_ta_stockbond=(1.1515791 0.512555460738297)) atmeans over(d_5ycrisis_hp_5pc) //To calculate the predicted economic effect of a hypothetical scenario in which the bank-market ratio falls from 3.2 in 1990 to 1.7 in 2011.

/*
---------------------------------------------------------------------------------------
                      |            Delta-method
                      |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------------+----------------------------------------------------------------
_at#d_5ycrisis_hp_5pc |
                 1 0  |   .0100474   .0039854     2.52   0.012     .0022362    .0178585
                 1 1  |  -.0190288   .0046977    -4.05   0.000    -.0282361   -.0098216
                 2 0  |   .0228505   .0006569    34.79   0.000      .021563     .024138
                 2 1  |   .0047167   .0039956     1.18   0.238    -.0031146    .0125479
---------------------------------------------------------------------------------------


"According to our estimates, this hypothetical decrease in the bank-market ratio would 
have been associated with an increase in growth of 1.3 percentage points per year 
in normal times and 2.4 percentage points during housing market crises."

--> To replicate 1.3pp during normal times, calculate .0228505 - .0100474 = 0.012803
--> To replicate 2.4pp during housing crises, calculate .0047167 - -.0190288 = 0.023746
*/


********************************************************************************
*FIGURE 8: Frequency of crises 
********************************************************************************

use X2_WorldBank_prepped, clear

drop if year<1990

local CRISISvars d_crisis_hp_5pc d_crisis_hp_10pc d_crisis_stkmkt_10pc d_crisis_stkmkt_20pc
foreach crisisvar in `CRISISvars' {
bys year: egen total_`crisisvar' = total(`crisisvar')
bys year: egen count_`crisisvar' = count(`crisisvar')
gen prop_`crisisvar' = total_`crisisvar' / count_`crisisvar'
bys year: egen mean_`crisisvar' = mean(`crisisvar')
}

gen d_crisis_hp_510pc = mean_d_crisis_hp_5pc - mean_d_crisis_hp_10pc
gen d_crisis_stkmkt_1020pc = mean_d_crisis_stkmkt_10pc - mean_d_crisis_stkmkt_20pc

graph bar d_crisis_hp_510pc mean_d_crisis_hp_10pc, stack ///
	over(year, relabel(1 "1990" 2 " " 3 " " 4 " " 5 " " 6 "1995" 7 " " 8 " " 9 " " 10 " " 11 "2000" 12 " " 13 " " 14 " " 15 " " 16 "2005" 17 " " 18 " " 19 " " 20 " " 21 "2010" 22 " ")) ///
	scale(1) ///
	ylabel(0 "0" .2 "20%" .4 "40%" .6 "60%" .8 "80%" 1 "100%", nogrid) ///
	name(mean_d_crisis_hp_10pc, replace) ///
	legend(order(1 "<5%" 2 "<10%") region(lcolor(white))) ///
	ytitle("") ///
		bar(1,color(gs0)) ///
		bar(2,color(gs10)) ///
	graphregion(margin(medsmall)) title("Housing price drop", size(medlarge))
	
graph bar d_crisis_stkmkt_1020pc mean_d_crisis_stkmkt_20pc, stack ///
	over(year, relabel(1 "1990" 2 " " 3 " " 4 " " 5 " " 6 "1995" 7 " " 8 " " 9 " " 10 " " 11 "2000" 12 " " 13 " " 14 " " 15 " " 16 "2005" 17 " " 18 " " 19 " " 20 " " 21 "2010" 22 " ")) ///
	scale(1) ///
	ylabel(0 "0" .2 "20%" .4 "40%" .6 "60%" .8 "80%" 1 "100%", nogrid) ///
	name(mean_d_crisis_stkmkt, replace) ///
	legend(order(1 "<10%" 2 "<20%") region(lcolor(white))) ///
		bar(1,color(gs0)) ///
		bar(2,color(gs10)) ///
			ytitle("") ///
	xsize(13) ysize(10) ///
	graphregion(margin(medsmall)) title("Stock price drop", size(medlarge))
	
graph combine mean_d_crisis_hp_10pc mean_d_crisis_stkmkt, ///
	scale(1) name("combine", replace) graphregion(margin(medsmall)) rows(1) ///
	l1title("Proportion of countries in which asset prices drop", size(medsmall))

graph display combine, ysize(10) xsize(13)

graph export Z_Fig8_combine_freqcrises.emf, replace 	


********************************************************************************
*FIGURE 5: Bank-market ratio and its components since 1990 in Europe versus Japan and the US
********************************************************************************

use X2_WorldBank_prepped, clear

/*
PREP DATA
*/
keep d_europe year countrycode ta_stockbond rgdp cncode_short countryname ta_gdp_composite stmktcap_composite prbond_composite
sort ta_stockbond
format rgdp %15.0g

drop if missing(ta_stockbond)

gen stmktcap = rgdp*(stmktcap_composite/100)
gen ta = rgdp*(ta_gdp_composite/100)
gen prbond = rgdp*(prbond_composite/100)

bys d_europe year: egen totaleu_ta = total(ta)
bys d_europe year: egen totaleu_stmktcap = total(stmktcap) 
bys d_europe year: egen totaleu_prbond = total(prbond) 
egen totaleu_stmktcap_prbond = rowtotal(totaleu_stmktcap totaleu_prbond)

gen totaleu_ta_stockbond = totaleu_ta / totaleu_stmktcap_prbond
replace totaleu_ta_stockbond = . if d_europe == 0

bys d_europe year: egen totaleu_rgdp = total(rgdp)
replace totaleu_rgdp = . if d_europe == 0
gen propeu_rgdp = rgdp/totaleu_rgdp

gen eu_stmktcap_gdp = 100*(totaleu_stmktcap / totaleu_rgdp)
gen eu_prbond_gdp = 100*(totaleu_prbond / totaleu_rgdp)
gen eu_ta_gdp = 100*( totaleu_ta / totaleu_rgdp)

********************************************************************************

graph twoway ///
	scatter totaleu_ta_stockbond year if d_europe==1, msymbol(O) lwidth(med) lpattern("--") msize(medsmall) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter ta_stockbond year if countrycode=="JPN", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter ta_stockbond year if countrycode=="USA", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///	
		graphregion(margin(medsmall)) legend(off) ///
		title("Bank-market ratio" "(bank assets divided by stock and bond market cap)") xtitle("") ylabel(0(1)5) xlabel(1990 (5) 2011) xsize(13) ysize(8) name("Str", replace)

graph export Z_Fig5a.emf, replace
		
graph twoway ///
	scatter eu_ta_gdp year if d_europe==1, msymbol(O) lwidth(med) lpattern("--") msize(medsmall) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter ta_gdp_composite year if countrycode=="JPN", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter ta_gdp_composite year if countrycode=="USA", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///	
		graphregion(margin(medsmall)) legend(rows(1) region(lcolor(white)) label(1 "Europe") label(2 "Japan") label(3 "US")) ///
		title("Bank assets" "/ GDP (%)") xtitle("") xlabel(1990 (10) 2011) xsize(13) ysize(10) scale(1.25) name("TA", replace)

graph twoway ///
	scatter eu_stmktcap_gdp year if d_europe==1, msymbol(O) lwidth(med) lpattern("--") msize(medsmall) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter stmktcap_composite year if countrycode=="JPN", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter stmktcap_composite year if countrycode=="USA", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///	
		graphregion(margin(medsmall)) legend(rows(1) region(lcolor(white)) label(1 "Europe") label(2 "Japan") label(3 "US")) ///
		title("Stock market cap" "/ GDP (%)") xtitle("") xlabel(1990 (10) 2011) xsize(13) ysize(10) scale(1.25) name("stmkt", replace)

graph twoway ///
	scatter eu_prbond_gdp year if d_europe==1, msymbol(O) lwidth(med) lpattern("--") msize(medsmall) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter prbond_composite year if countrycode=="JPN", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter prbond_composite year if countrycode=="USA", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///	
		graphregion(margin(medsmall)) legend(rows(1) region(lcolor(white)) label(1 "Europe") label(2 "Japan") label(3 "US")) ///
		title("Bond market cap" "/ GDP (%)") xtitle("") ylabel(0 (50) 200) xlabel(1990 (10) 2011) xsize(13) ysize(10) scale(1.25) name("prbond", replace)
		
grc1leg TA stmkt prbond, ///
	holes(2) /// 
	scale(1) name("combine", replace) graphregion(margin(medsmall)) legendfrom(TA) rows(1)
	
graph display combine, ysize(8) xsize(13)
		
graph export Z_Fig5b.emf, replace


********************************************************************************
*FIGURE 6: Bank-market ratio in 2011 in European countries versus the rest of the world
********************************************************************************

use X2_WorldBank_prepped, clear

format ngdp %10.0g
keep if year==2011
drop if missing(ta_stockbond)

keep year countrycode ta_stockbond rgdp ngdp cncode_short d_europe
sort ta_stockbond

gen keep = 0
replace keep = 1 if rgdp>8
replace keep = 0 if countrycode=="LUX"
keep if keep==1
drop keep

gen ta_stockbond_eu = ta_stockbond if d_europe==1
gen ta_stockbond_row = ta_stockbond if d_europe==0

graph bar ta_stockbond_eu ta_stockbond_row if year==2011, ///
	horizontal ///
	over(cncode_short, sort(ta_stockbond)) ///
	nofill ///
	scale(0.85) bar(1,color(gs0)) bar(2,color(gs12)) ///
	xsize(13) ysize(18) legend(region(lcolor(white))) ///
	ylabel(0 (2) 8, nogrid) ///
	legend(order(1 "European" 2 "non-European") size(medlarge)) ///
	b1title("Bank-market ratio in 2011", size(medlarge)) b2title("(bank assets divided by stock and bond market cap)", size(med)) ///
	graphregion(margin(medsmall)) name(paper)
	
	graph export Z_Fig6_structure2011.emf, replace 


/*******************************************************************************
*Extension: Pooling both crises in one specification (NOT REPORTED IN THE PAPER)
*******************************************************************************/

use X2_WorldBank_prepped_5y_nonoverlap, clear

*table 3 equiv
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc ///
	c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)

*table 4 equiv
xtreg mean_d1rgdp c.mean_STR_ta_stockbond##d_5ycrisis_hp_5pc ///
	c.mean_STR_ta_stockbond##d_5ycrisis_st_10pc ///
	i.time_period if time_period!=5, ///
	vsquish fe vce(cluster cncode)
	
margins, at(mean_STR_ta_stockbond=(-.5822387 -.5 (0.1) 1.5 1.529542)) over(d_5ycrisis_hp_5pc d_5ycrisis_st_10pc) atmeans

marginsplot, ///
	recastci(rarea) ci1(color(gs14)) ci2(color(gs9)) ///
	recast(line) plot1(lcolor(gs7) lpattern("--") lwidth(medthick)) ///
				plot2(lcolor(gs0) lpattern(dot) lwidth(medthick)) ///
				xlabel(-.5822387 "5" .1244442 "25" .6073711 "50" 1.081815 "75" 1.710237 "95") ///
	legend(rows(2) order(- "Predicted effect during:" 5 "stock crises" 4 "no crisis" 3 "housing crises") region(lcolor(white))) ///
	xtitle("") ///
	ytitle("" , size(large)) ///
		ylabel(-.06 " " -.04 "-4%" 0 "0" .04 "4%" .08 "8%") ///
	///
	title("   ", size(large)) ///
	ysize(1) xsize(1) ///  
		graphregion(margin(vsmall)) ///
	name(Fig10a, replace) scale(1)
	
*table 5 equiv
xtreg mean_d1rgdp c.mean_STR_pcrd_stmktcap##d_5ycrisis_hp_5pc ///
	c.mean_STR_pcrd_stmktcap##d_5ycrisis_st_10pc ///
	i.time_period, ///
	vsquish fe vce(cluster cncode)
	
