/*******************************************************************************
Sam Langfield and Marco Pagano (2015)
"Bank bias in Europe: Effects on Systemic Risk and Growth"
Economic Policy
*******************************************************************************/

/*******************************************************************************
Risk regressions
*******************************************************************************/

/*******************************************************************************
HOUSEKEEPING
*******************************************************************************/

version 13.0

*Set your working directory here:
cd "C:\Users\SPL\Dropbox\Research\Pagano-Langfield_EP_Bank-bias\Data\CLEAN"

clear all
cap log close
set more off
set scheme s1color

insheet using B_Figure11.csv, comma

/*******************************************************************************
LABEL VARIABLES
*******************************************************************************/

label var bbg_ticker "Bloomberg ticker"
label var bs_tot_asset_eur "Total book value of assets in EUR (source: Bloomberg)"
label var ta_gdp_composite "Bank TA / GDP: composite series from Helgi and historical TA"
label var ta "Total banking system assets at the country-level in EUR"
label var ngdp "Nominal GDP at the country-level in EUR"

/*******************************************************************************
FIGURE 11
*******************************************************************************/

*Gen important variables

bys year: egen ta_top20 = total(bs_tot_asset_eur)

bys year countrycode: gen dup = _n
bys year: egen delete = sum(ngdp) if (dup==1)
bys year: egen eu_gdp = mean(delete)
drop delete dup

bys year countrycode: gen dup = _n
bys year: egen delete = sum(ta) if (dup==1)
bys year: egen eu_ta = mean(delete)
drop delete dup

gen c20 = 100*(ta_top20 / eu_ta)
gen c20_gdp = 100*(ta_top20 / eu_gdp)
gen ta_gdp_eu = 100*(eu_ta / eu_gdp)

*Duplicates drop

duplicates drop year, force
drop company_name bbg_ticker bs_tot_asset_eur countrycode ta ngdp ta_gdp_composite

*Gen counterfactual
gen c20_gdp_1997 = 50.57802
gen change = c20_gdp - c20_gdp_1997
gen counterfactual = ta_gdp_eu - change

*Figure 11
twoway ///
	scatter ta_gdp_eu year, c(direct) lpattern(solid) lwidth(thick) lcolor(gs0) msymbol(none) mcolor(gs0) || ///
	scatter counterfactual year, c(direct) lpattern("--") lwidth(medium) lcolor(gs10) msymbol(none) mcolor(gs0) mcolor(orange) xlabel(1997 (2) 2013) ///
	xtitle(" ") legend(region(color(white)) rows(1) label(1 "Actual") label(2 "Counterfactual")) scale(1.25) xsize(7.5) ysize(6) ytitle(" ") ///
	caption("The counterfactual series shows EU total assets to GDP if" "the EU's top 20 banks had grown in line with GDP since 1997.", size(small)) ///
	ylabel(150 "150" 250 "250" 350 "350") name("eu", replace) graphregion(margin(vsmall))
	
graph export Z_Fig11.emf, replace
